@@ -10,7 +10,7 @@ logLik.mpp <- function(object, SNOWcluster=NULL, ...){
     evalpts0 <- data[((data[,"time"] <= TT[2]) &
                      (data[,"time"] >= TT[1])), ]
     if (!is.null(SNOWcluster)){
-        if (!require(snow)) stop("The R package `snow' is required")
+        if (!require(parallel)) stop("The R package `parallel' is required")
         if (inherits(SNOWcluster, "cluster")){
             #  swap order of evalpts & data, TT & tplus not needed
             gif_cluster <- function(evalpts, data, params)
@@ -36,7 +36,7 @@ logLik.mpp <- function(object, SNOWcluster=NULL, ...){
                 }
             }
             w[[m]] <- evalpts0[(n1+1):n,]
-            L0 <- snow::clusterApply(SNOWcluster, w, gif_cluster,
+            L0 <- parallel::clusterApply(SNOWcluster, w, gif_cluster,
                                data=data, params=gparams)
             L1 <- sum(log(L0[[1]]))
             for (i in 2:m) L1 <- L1 + sum(log(L0[[i]]))
